BitStreamWriter

Struct BitStreamWriter 

pub struct BitStreamWriter<'a> { /* private fields */ }

Implementations

Source

impl<'a> BitStreamWriter<'a>

pub fn new(buffer: &'a mut Vec<u8>) -> Self

Create a new LSB-first writer

pub fn slice(&self) -> &[u8]

Return slice of buffer

pub fn set_marker(&mut self, pos: Option<usize>)

Set marker at specific position or current byte

pub fn reset_marker(&mut self)

Unset marker

pub fn slice_marker(&self, to: Option<usize>) -> &[u8]

Return slice from marker (or start if marker is unset) to specific position or current byte If crypto is set, it will return the unencrypted (cached) slice. This is different from other slice methods which always returns the raw buffer slice.

pub fn set_crypto(&mut self, crypto: Option<Box<dyn CryptoStream>>)

Set crypto stream

pub fn reset_crypto(&mut self)

Remove crypto stream

pub fn byte_pos(&self) -> usize

Get byte position of writer

pub fn write_bit(&mut self, val: bool)

Write a single bit

pub fn write_small(&mut self, val: u8, bits: u8)

Write 1-8 bits (LSB-first)

pub fn write_byte(&mut self, byte: u8)

Write a full byte, starting at the next byte boundary

pub fn write_bytes(&mut self, data: &[u8])

Write a slice of bytes, starting at the next byte boundary

pub fn write_dyn_int(&mut self, val: u128)

Write a dynamic int, starting at the next byte bounary The last bit is used as a continuation flag for the next byte

pub fn write_fixed_int<const S: usize, T: FixedInt<S>>(&mut self, val: T)

Write a integer of fixed size to the buffer

pub fn align_byte(&mut self)

Align the stream to the next byte boundary

pub fn reset(&mut self)

Reset writing position

pub fn len(&self) -> usize

Get buffer length