CryptoStream

Trait CryptoStream 

pub trait CryptoStream {
    // Required methods
    fn apply_keystream_byte(&mut self, b: u8) -> u8;
    fn apply_keystream(&mut self, slice: &[u8]) -> &[u8] ;
    fn get_plaintext(&self) -> &[u8] ;
}
Crypto Stream

Required Methods

fn apply_keystream_byte(&mut self, b: u8) -> u8

Applies the keystream byte to the given byte and returns the result.

fn apply_keystream(&mut self, slice: &[u8]) -> &[u8]

Applies the keystream to the given slice and returns the result.

fn get_plaintext(&self) -> &[u8]

Get the underlying plaintext buffer

Implementors